function[Satisfied, Edges]=Annealed(Lambdamu,Lambdasig,Links,Zeta)

%Predetermined Values
Small=0.000000001;
Infi=10000000000;
eqTime=100;
eqCount=0;
NoOfSteps=3000;

N=length(Lambdamu); %Number of nodes in the network

%Writing the Links vector as a Matrix of connections
[NeighbourM,NeighbourCM,NeighbourICon]=MakingNeighbourMatrixCM(Links,N);

%Starting values of A, B and Y
Max=max(NeighbourICon);
A=zeros(N,Max);
B=ones(N,Max);
Y=zeros(N,Max);

%Exhaustively and randomly choosing all trees for iterations
LLinks=[Links(1,:) Links(2,:); Links(2,:) Links(1,:)];

for j=0:length(LLinks):(NoOfSteps*N)
    for i=1:length(LLinks)
        a=randi(length(LLinks)-i+1);
        Randi(:,i+j)=LLinks(:,a);
        b=LLinks(:,a);
        LLinks(:,a)=[];
        LLinks=[LLinks b];
    end
end

for t=1:NoOfSteps*N
   
    %Assigning Nodes J and I
    nodeJ=Randi(1,t);
    connectivity=NeighbourICon(nodeJ);
    nodeI=Randi(2,t);
    cavityI=find(NeighbourM(nodeJ,:)==nodeI);
    cavityJ=find(NeighbourM(nodeI,:)==nodeJ);
    
    %Rewriting for ease
    Yij=Y(nodeI,cavityJ);
    Yji=Y(nodeJ,cavityI);
    Aij=A(nodeI,cavityJ);
    Aji=A(nodeJ,cavityI);
    Bij=B(nodeI,cavityJ);
    Bji=B(nodeJ,cavityI);
    mu=Lambdamu(nodeJ);
    sig=Lambdasig(nodeJ);

    %Assuming the quadratic transportation cost
    Phiij1=Y(nodeI,cavityJ); %*
    Phiij2=1; %*
    
    %Obtaining values of A, B and Y from descendants k
    for k=1:connectivity
        Ajk(k)=A(nodeJ,k);
        Bjk(k)=B(nodeJ,k);
        Yjk(k)=Y(nodeJ,k);
        Phijk1(k)=Y(nodeJ,k); %*
        Phijk2(k)=1; %*
    end
    
    %Summing the descendants for calculations in mu
    tempd1=0;
    tempd2=0;
    
    for k=1:connectivity
        if k~=cavityI
            tempd1=tempd1+Yjk(k)-((Ajk(k)+Phijk1(k))/(Bjk(k)+Phijk2(k)));
            tempd2=tempd2+(1/(Phijk2(k)+Bjk(k)));
        end
    end
    
    %Calculating Mu
    x=Yij-tempd1;
    S2=sqrt(2);
    mu=mu+(S2*sig*erfinv((2*Zeta)-1));
    
    Pos=0;
    tempmu=(mu-x)/tempd2;
    if tempmu>0
        tempmu=0;
        Pos=1;
    end

    %Messages before changing to check convergence
    preA=Aij;
    preB=Bij;
    preY=Yij;

    %Calculating new Aij and Bij
    A(nodeI,cavityJ)=-tempmu;
    
    if Pos==0
        B(nodeI,cavityJ)=1/tempd2;
    else
        B(nodeI,cavityJ)=0;
    end
    
    Aij=A(nodeI,cavityJ); %ease
    Bij=B(nodeI,cavityJ); %ease
    
    %Calculating new Yij
    Y(nodeI,cavityJ)=(((Bij*Yij)-Aij-(Bji*Yji)+Aji-Phiij1+(Phiij2*Yij))/(Bij+Bji+Phiij2));

    %ConvergenceCheck
    fieldChange=abs(A(nodeI,cavityJ)-preA)+abs(B(nodeI,cavityJ)-preB)+abs(Y(nodeI,cavityJ)-preY);

    if fieldChange<Small
        eqCount=eqCount+1;
    else
        eqCount=0;
    end
    
    %Finish if converged.
    if eqCount>eqTime*N
        fprintf('Break at %5.0f Iterations for N=%3.0f \n',t,N);
        break;
    end
    
end

[Satisfied,TotalSat,TotalLam]=Check(Y,Lambdamu,NeighbourICon,Small);
[Edges]=BackYAsEdgesEdges(Links,Y,NeighbourM,Small,NeighbourCM);

end

%* Change these is quadratic transportation cost changes.